/*
    Copyright (c) 2009 Volker Krause <vkrause@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#ifndef AKONADICONSOLE_DBBROWSER_H
#define AKONADICONSOLE_DBBROWSER_H

#include "ui_dbbrowser.h"

class QSqlTableModel;

class DbBrowser : public QWidget
{
    Q_OBJECT
public:
    explicit DbBrowser(QWidget *parent = nullptr);

private Q_SLOTS:
    void refreshClicked();
    void onSortIndicatorChanged(int column, Qt::SortOrder order);

private:
    Ui::DbBrowser ui;
    QSqlTableModel *mTableModel = nullptr;
};

#endif
